import { DataEnum, DataEnumToSerializerTuple, Nullable, NumberSerializer, Option, PublicKey, PublicKeyInput, ScalarEnum, Serializer, SerializerInterface, StructToSerializerTuple, WrapInSerializer } from '@lorisleiva/js-core';
export declare class BeetSerializer implements SerializerInterface {
    tuple<T extends any[], U extends T = T>(items: WrapInSerializer<[...T], [...U]>, description?: string): Serializer<T, U>;
    vec<T, U extends T = T>(itemSerializer: Serializer<T, U>, prefix?: NumberSerializer, description?: string): Serializer<T[], U[]>;
    array<T, U extends T = T>(itemSerializer: Serializer<T, U>, size: number, description?: string): Serializer<T[], U[]>;
    map<TK, TV, UK extends TK = TK, UV extends TV = TV>(keySerializer: Serializer<TK, UK>, valueSerializer: Serializer<TV, UV>, prefix?: NumberSerializer, description?: string): Serializer<Map<TK, TV>, Map<UK, UV>>;
    set<T, U extends T = T>(itemSerializer: Serializer<T, U>, prefix?: NumberSerializer, description?: string): Serializer<Set<T>, Set<U>>;
    option<T, U extends T = T>(itemSerializer: Serializer<T, U>, prefix?: NumberSerializer, description?: string): Serializer<Option<T>, Option<U>>;
    fixedOption<T, U extends T = T>(itemSerializer: Serializer<T, U>, prefix?: NumberSerializer, description?: string): Serializer<Option<T>, Option<U>>;
    nullable<T, U extends T = T>(itemSerializer: Serializer<T, U>, prefix?: NumberSerializer, description?: string): Serializer<Nullable<T>, Nullable<U>>;
    fixedNullable<T, U extends T = T>(itemSerializer: Serializer<T, U>, prefix?: NumberSerializer, description?: string): Serializer<Nullable<T>, Nullable<U>>;
    struct<T extends object, U extends T = T>(fields: StructToSerializerTuple<T, U>, description?: string): Serializer<T, U>;
    enum<T>(constructor: ScalarEnum<T> & {}, description?: string): Serializer<T>;
    dataEnum<T extends DataEnum, U extends T = T>(variants: DataEnumToSerializerTuple<T, U>, prefix?: NumberSerializer, description?: string): Serializer<T, U>;
    fixed<T, U extends T = T>(bytes: number, child: Serializer<T, U>, description?: string): Serializer<T, U>;
    string(prefix?: NumberSerializer, content?: Serializer<string>, description?: string): Serializer<string>;
    fixedString(bytes: number, content?: Serializer<string>, description?: string): Serializer<string>;
    bool(size?: NumberSerializer, description?: string): Serializer<boolean>;
    get unit(): Serializer<void>;
    get u8(): Serializer<number>;
    get u16(): Serializer<number>;
    get u32(): Serializer<number>;
    get u64(): Serializer<number | bigint, bigint>;
    get u128(): Serializer<number | bigint, bigint>;
    get i8(): Serializer<number>;
    get i16(): Serializer<number>;
    get i32(): Serializer<number>;
    get i64(): Serializer<number | bigint, bigint>;
    get i128(): Serializer<number | bigint, bigint>;
    get f32(): Serializer<number>;
    get f64(): Serializer<number>;
    get bytes(): Serializer<Uint8Array>;
    get publicKey(): Serializer<PublicKeyInput, PublicKey>;
}
